@@ -628,8 +628,6 @@ var namespacezypp =
     [ "asUserStringDescription", "namespacezypp.html#a4e5a681d5e1f1c10528eefa059f0fc57", null ],
     [ "ZYPP_DECLARE_FLAGS", "namespacezypp.html#a96f6758cc67e7a05c4450a141d9b6998", null ],
     [ "operator<<", "namespacezypp.html#a747115c895642ca3b201e8190af4f46a", null ],
-    [ "ImZYPPER", "namespacezypp.html#a8efd2ad5408299e74b3d5dc92e091d31", null ],
-    [ "singleTransInEnv", "namespacezypp.html#acad8a6603c18cce15b1ca094721fab2b", null ],
     [ "singleTransEnabled", "namespacezypp.html#ab8574254622efb3ee0f7328faa0dad72", null ],
     [ "isPreUsrmerge", "namespacezypp.html#a426314dd04fadde7db943f2bc305f269", null ],
     [ "transactionWillUsrmerge", "namespacezypp.html#ad8db692be4cb34506ba8b876514f2082", null ],
