@@ -1,7 +1,5 @@
 var NAVTREEINDEX100 =
 {
-"namespacezypp_1_1sat.html#a75e7ebace278152247eab16eb8e0c69e":[3,0,10,37,78],
-"namespacezypp_1_1sat.html#a7921c46e106e90d039e9a0d4352eb945":[3,0,10,37,67],
 "namespacezypp_1_1sat.html#a80455a75daf689a776e48922e6d997f3":[3,0,10,37,59],
 "namespacezypp_1_1sat.html#a84c1c3effec6e67ef3d5bb5568f7dd92":[3,0,10,37,30],
 "namespacezypp_1_1sat.html#a8509813dd1e81332432a2305ae678866":[3,0,10,37,39],
@@ -249,5 +247,7 @@ var NAVTREEINDEX100 =
 "namespacezypp_1_1str.html#ab99233bc354d63462368ae51d853f278":[3,0,10,40,19],
 "namespacezypp_1_1str.html#abb38e854929d0ee09b809bad87fa5c57":[3,0,10,40,74],
 "namespacezypp_1_1str.html#abdf70f090692e63a7aae9bd2d501d447":[3,0,10,40,51],
-"namespacezypp_1_1str.html#abe39d92b7953c0988b3ed4499ffd7729":[3,0,10,40,56]
+"namespacezypp_1_1str.html#abe39d92b7953c0988b3ed4499ffd7729":[3,0,10,40,56],
+"namespacezypp_1_1str.html#abfda3e5118b6a8a27a651344cbd3ea2a":[3,0,10,40,82],
+"namespacezypp_1_1str.html#ac2659ed4b8cab2f2cecb655983c45007":[3,0,10,40,37]
 };
