@@ -1,7 +1,5 @@
 var NAVTREEINDEX111 =
 {
-"structzypp_1_1Option.html#a399a0d15159b7e0502abfcce7830932b":[4,0,7,158,5],
-"structzypp_1_1Option.html#a3b3e180cc72bce7bdc32dd4389410f6e":[3,0,10,167,1],
 "structzypp_1_1Option.html#a3b3e180cc72bce7bdc32dd4389410f6e":[4,0,7,158,1],
 "structzypp_1_1Option.html#a66d2cc07b0f67f2bf5fa681404288e08":[3,0,10,167,0],
 "structzypp_1_1Option.html#a66d2cc07b0f67f2bf5fa681404288e08":[4,0,7,158,0],
@@ -249,5 +247,7 @@ var NAVTREEINDEX111 =
 "structzypp_1_1PoolQueryAttr.html#aaeeab3c6e5a5720d8c656110e3dff45b":[4,0,7,175,0],
 "structzypp_1_1PoolQueryAttr.html#ab0a295e896e993589091ea0e4da9595b":[3,0,10,184,3],
 "structzypp_1_1PoolQueryAttr.html#ab0a295e896e993589091ea0e4da9595b":[4,0,7,175,3],
-"structzypp_1_1PoolQueryAttr.html#abf7a9879c5760780ca5d129cefb7ab45":[3,0,10,184,15]
+"structzypp_1_1PoolQueryAttr.html#abf7a9879c5760780ca5d129cefb7ab45":[3,0,10,184,15],
+"structzypp_1_1PoolQueryAttr.html#abf7a9879c5760780ca5d129cefb7ab45":[4,0,7,175,15],
+"structzypp_1_1PoolQueryAttr.html#afe531492b0484fe4c46b46d0caf9d6dc":[3,0,10,184,10]
 };
