@@ -1,5 +1,7 @@
 var NAVTREEINDEX40 =
 {
+"classzypp_1_1base_1_1Flags.html":[4,0,7,1,2],
+"classzypp_1_1base_1_1Flags.html#a016d1a88525b85e27413c9973129423e":[3,0,10,2,3,21],
 "classzypp_1_1base_1_1Flags.html#a016d1a88525b85e27413c9973129423e":[4,0,7,1,2,21],
 "classzypp_1_1base_1_1Flags.html#a12a4d228626244ff5c995f972eb318ca":[3,0,10,2,3,7],
 "classzypp_1_1base_1_1Flags.html#a12a4d228626244ff5c995f972eb318ca":[4,0,7,1,2,7],
@@ -247,7 +249,5 @@ var NAVTREEINDEX40 =
 "classzypp_1_1base_1_1logger_1_1Loglinebuf.html#ad2d84e7463d1f847339637acf6531abb":[4,0,7,1,0,1,6],
 "classzypp_1_1base_1_1logger_1_1Loglinebuf.html#ad94e439e84717fedd778e412e148ab31":[3,0,10,2,0,1,9],
 "classzypp_1_1base_1_1logger_1_1Loglinebuf.html#ad94e439e84717fedd778e412e148ab31":[4,0,7,1,0,1,9],
-"classzypp_1_1base_1_1logger_1_1Loglinebuf.html#ae6ae9ebadd086e9e149e36d323173d3b":[3,0,10,2,0,1,14],
-"classzypp_1_1base_1_1logger_1_1Loglinebuf.html#ae6ae9ebadd086e9e149e36d323173d3b":[4,0,7,1,0,1,14],
-"classzypp_1_1base_1_1logger_1_1Loglinebuf.html#af82367a7ff7ceb46f6cd982f430652f4":[3,0,10,2,0,1,5]
+"classzypp_1_1base_1_1logger_1_1Loglinebuf.html#ae6ae9ebadd086e9e149e36d323173d3b":[3,0,10,2,0,1,14]
 };
