@@ -1,5 +1,7 @@
 var NAVTREEINDEX57 =
 {
+"classzypp_1_1pool_1_1ByIdent.html#a82af126e405a688d30d9f16c00256afc":[3,0,10,29,0,1],
+"classzypp_1_1pool_1_1ByIdent.html#a82af126e405a688d30d9f16c00256afc":[4,0,7,26,0,1],
 "classzypp_1_1pool_1_1ByIdent.html#a97fc46bac892eff6832790fbdf79d78f":[3,0,10,29,0,3],
 "classzypp_1_1pool_1_1ByIdent.html#a97fc46bac892eff6832790fbdf79d78f":[4,0,7,26,0,3],
 "classzypp_1_1pool_1_1ByIdent.html#abda0b8c7186662ea79dd459074cf829b":[3,0,10,29,0,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX57 =
 "classzypp_1_1repo_1_1RepoException.html":[4,0,7,27,10],
 "classzypp_1_1repo_1_1RepoException.html#a09a2e5cb96d94feb55e7a97bbcf959ba":[3,0,10,32,11,5],
 "classzypp_1_1repo_1_1RepoException.html#a09a2e5cb96d94feb55e7a97bbcf959ba":[4,0,7,27,10,5],
-"classzypp_1_1repo_1_1RepoException.html#a51db59de128e7602991a9170f7772578":[3,0,10,32,11,0],
-"classzypp_1_1repo_1_1RepoException.html#a51db59de128e7602991a9170f7772578":[4,0,7,27,10,0],
-"classzypp_1_1repo_1_1RepoException.html#aad20eff8072100b6d3d8b52e4e4b7329":[3,0,10,32,11,8]
+"classzypp_1_1repo_1_1RepoException.html#a51db59de128e7602991a9170f7772578":[3,0,10,32,11,0]
 };
