@@ -1,5 +1,7 @@
 var NAVTREEINDEX58 =
 {
+"classzypp_1_1repo_1_1RepoException.html#a51db59de128e7602991a9170f7772578":[4,0,7,27,10,0],
+"classzypp_1_1repo_1_1RepoException.html#aad20eff8072100b6d3d8b52e4e4b7329":[3,0,10,32,11,8],
 "classzypp_1_1repo_1_1RepoException.html#aad20eff8072100b6d3d8b52e4e4b7329":[4,0,7,27,10,8],
 "classzypp_1_1repo_1_1RepoException.html#ab010996cd2a6fd5d96b573f778cba058":[3,0,10,32,11,2],
 "classzypp_1_1repo_1_1RepoException.html#ab010996cd2a6fd5d96b573f778cba058":[4,0,7,27,10,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX58 =
 "classzypp_1_1repo_1_1RpmSigCheckException.html#a18d841f5434dcc07da29f0645915d7c6":[3,0,10,32,29,2],
 "classzypp_1_1repo_1_1RpmSigCheckException.html#a18d841f5434dcc07da29f0645915d7c6":[4,0,7,27,28,2],
 "classzypp_1_1repo_1_1RpmSigCheckException.html#ae8a7c07bd80a3a07f8a4f99c1b9b4270":[3,0,10,32,29,0],
-"classzypp_1_1repo_1_1RpmSigCheckException.html#ae8a7c07bd80a3a07f8a4f99c1b9b4270":[4,0,7,27,28,0],
-"classzypp_1_1repo_1_1RpmSigCheckException.html#af742eb2b3689c7900432d3d479058c61":[3,0,10,32,29,1],
-"classzypp_1_1repo_1_1RpmSigCheckException.html#af742eb2b3689c7900432d3d479058c61":[4,0,7,27,28,1]
+"classzypp_1_1repo_1_1RpmSigCheckException.html#ae8a7c07bd80a3a07f8a4f99c1b9b4270":[4,0,7,27,28,0]
 };
