@@ -1,5 +1,7 @@
 var NAVTREEINDEX62 =
 {
+"classzypp_1_1sat_1_1Queue.html#a5b24fc04d89f3d9ebc11efd9ad64dd1c":[4,0,7,31,12,4],
+"classzypp_1_1sat_1_1Queue.html#a6b5c1b2852eeb360951e9b987ee3976a":[3,0,10,37,11,6],
 "classzypp_1_1sat_1_1Queue.html#a6b5c1b2852eeb360951e9b987ee3976a":[4,0,7,31,12,6],
 "classzypp_1_1sat_1_1Queue.html#a6c2507f86d3cbab3258c9201dc964560":[3,0,10,37,11,12],
 "classzypp_1_1sat_1_1Queue.html#a6c2507f86d3cbab3258c9201dc964560":[4,0,7,31,12,12],
@@ -247,7 +249,5 @@ var NAVTREEINDEX62 =
 "classzypp_1_1sat_1_1SolvAttr.html#ad999225793acf48096351d2023614520":[4,0,7,31,16,12],
 "classzypp_1_1sat_1_1SolvAttr.html#ad9a29008fb130a2c7137ca4c1a135c55":[3,0,10,37,15,53],
 "classzypp_1_1sat_1_1SolvAttr.html#ad9a29008fb130a2c7137ca4c1a135c55":[4,0,7,31,16,53],
-"classzypp_1_1sat_1_1SolvAttr.html#ada31f7d7b3ce3bd74c7875a1592ab92a":[3,0,10,37,15,48],
-"classzypp_1_1sat_1_1SolvAttr.html#ada31f7d7b3ce3bd74c7875a1592ab92a":[4,0,7,31,16,48],
-"classzypp_1_1sat_1_1SolvAttr.html#add4b67f1d14062273aa7234c1fbde91d":[3,0,10,37,15,8]
+"classzypp_1_1sat_1_1SolvAttr.html#ada31f7d7b3ce3bd74c7875a1592ab92a":[3,0,10,37,15,48]
 };
