@@ -1,5 +1,7 @@
 var NAVTREEINDEX67 =
 {
+"classzypp_1_1solver_1_1detail_1_1SolverQueueItemInstallOneOf.html#a4f2ea1a1ed3489a669aa78f9d0136106":[3,0,10,39,0,8,0],
+"classzypp_1_1solver_1_1detail_1_1SolverQueueItemInstallOneOf.html#a4f2ea1a1ed3489a669aa78f9d0136106":[4,0,7,33,0,8,0],
 "classzypp_1_1solver_1_1detail_1_1SolverQueueItemInstallOneOf.html#a5590f8c87a4442a65d0a0c37ed66c8ab":[3,0,10,39,0,8,8],
 "classzypp_1_1solver_1_1detail_1_1SolverQueueItemInstallOneOf.html#a5590f8c87a4442a65d0a0c37ed66c8ab":[4,0,7,33,0,8,8],
 "classzypp_1_1solver_1_1detail_1_1SolverQueueItemInstallOneOf.html#a82ff33011cbd0f373a92f3bc49b3459e":[3,0,10,39,0,8,6],
@@ -247,7 +249,5 @@ var NAVTREEINDEX67 =
 "classzypp_1_1target_1_1CommitPackageCache.html#a629a04c5b12c489ef32d47eeec3fb371":[3,0,10,43,1,9],
 "classzypp_1_1target_1_1CommitPackageCache.html#a629a04c5b12c489ef32d47eeec3fb371":[4,0,7,36,1,9],
 "classzypp_1_1target_1_1CommitPackageCache.html#a79fdbc2bb1fd954c9396e29960276cc4":[3,0,10,43,1,6],
-"classzypp_1_1target_1_1CommitPackageCache.html#a79fdbc2bb1fd954c9396e29960276cc4":[4,0,7,36,1,6],
-"classzypp_1_1target_1_1CommitPackageCache.html#a7e680ec16e007288de75b78ee303e610":[3,0,10,43,1,7],
-"classzypp_1_1target_1_1CommitPackageCache.html#a7e680ec16e007288de75b78ee303e610":[4,0,7,36,1,7]
+"classzypp_1_1target_1_1CommitPackageCache.html#a79fdbc2bb1fd954c9396e29960276cc4":[4,0,7,36,1,6]
 };
