@@ -1,5 +1,7 @@
 var NAVTREEINDEX70 =
 {
+"classzypp_1_1target_1_1rpm_1_1BinHeader.html#aa1f90abc1086ba3e7eab2716fbd8dcc2":[4,0,7,36,0,1,6],
+"classzypp_1_1target_1_1rpm_1_1BinHeader.html#aacef3cbc2ca0b3f4f1d446714eadc79a":[3,0,10,43,0,2,17],
 "classzypp_1_1target_1_1rpm_1_1BinHeader.html#aacef3cbc2ca0b3f4f1d446714eadc79a":[4,0,7,36,0,1,17],
 "classzypp_1_1target_1_1rpm_1_1BinHeader.html#ab2c6b655285e1493aa5f520a45a785c3":[3,0,10,43,0,2,13],
 "classzypp_1_1target_1_1rpm_1_1BinHeader.html#ab2c6b655285e1493aa5f520a45a785c3":[4,0,7,36,0,1,13],
@@ -247,7 +249,5 @@ var NAVTREEINDEX70 =
 "classzypp_1_1target_1_1rpm_1_1RpmDbNotOpenException.html#a481f5cc95e2373c4f9d2224955684e1b":[4,0,7,36,0,19,0],
 "classzypp_1_1target_1_1rpm_1_1RpmDbNotOpenException.html#a905a4a43b01013656c7c74789f79b3ea":[3,0,10,43,0,20,2],
 "classzypp_1_1target_1_1rpm_1_1RpmDbNotOpenException.html#a905a4a43b01013656c7c74789f79b3ea":[4,0,7,36,0,19,2],
-"classzypp_1_1target_1_1rpm_1_1RpmDbOpenException.html":[3,0,10,43,0,21],
-"classzypp_1_1target_1_1rpm_1_1RpmDbOpenException.html":[4,0,7,36,0,20],
-"classzypp_1_1target_1_1rpm_1_1RpmDbOpenException.html#a2117399fd1de4eb303d4b0022153c69b":[3,0,10,43,0,21,4]
+"classzypp_1_1target_1_1rpm_1_1RpmDbOpenException.html":[3,0,10,43,0,21]
 };
