@@ -1,5 +1,7 @@
 var NAVTREEINDEX79 =
 {
+"classzyppng_1_1CurlMultiPartHandler.html#a60d0fb7eb4536f850ac56259de4f7bcd":[3,0,13,72,35],
+"classzyppng_1_1CurlMultiPartHandler.html#a60d0fb7eb4536f850ac56259de4f7bcd":[4,0,9,34,35],
 "classzyppng_1_1CurlMultiPartHandler.html#a72d2c813f2e73a08c3c594babd33a5fc":[3,0,13,72,37],
 "classzyppng_1_1CurlMultiPartHandler.html#a72d2c813f2e73a08c3c594babd33a5fc":[4,0,9,34,37],
 "classzyppng_1_1CurlMultiPartHandler.html#a76087dba96740ce6026218652f721d15":[3,0,13,72,22],
@@ -247,7 +249,5 @@ var NAVTREEINDEX79 =
 "classzyppng_1_1HeaderValue.html#a4a17738c4c6491f69450c21756703263":[3,0,13,93,17],
 "classzyppng_1_1HeaderValue.html#a4a17738c4c6491f69450c21756703263":[4,0,9,55,17],
 "classzyppng_1_1HeaderValue.html#a4bb0462b5c42fbc9625ad95215fe368e":[3,0,13,93,12],
-"classzyppng_1_1HeaderValue.html#a4bb0462b5c42fbc9625ad95215fe368e":[4,0,9,55,12],
-"classzyppng_1_1HeaderValue.html#a54c26aa37c7a6cc6e76958eb4d295143":[3,0,13,93,13],
-"classzyppng_1_1HeaderValue.html#a54c26aa37c7a6cc6e76958eb4d295143":[4,0,9,55,13]
+"classzyppng_1_1HeaderValue.html#a4bb0462b5c42fbc9625ad95215fe368e":[4,0,9,55,12]
 };
