@@ -1,5 +1,7 @@
 var NAVTREEINDEX80 =
 {
+"classzyppng_1_1HeaderValue.html#a54c26aa37c7a6cc6e76958eb4d295143":[3,0,13,93,13],
+"classzyppng_1_1HeaderValue.html#a54c26aa37c7a6cc6e76958eb4d295143":[4,0,9,55,13],
 "classzyppng_1_1HeaderValue.html#a60dc05b2400b1d08f5ea5ae77e625676":[3,0,13,93,23],
 "classzyppng_1_1HeaderValue.html#a60dc05b2400b1d08f5ea5ae77e625676":[4,0,9,55,23],
 "classzyppng_1_1HeaderValue.html#a6c3804a2bc64d6eaf0e4293317c182a7":[3,0,13,93,0],
@@ -247,7 +249,5 @@ var NAVTREEINDEX80 =
 "classzyppng_1_1IODevice.html#ad24acd3ee7786444fba1d441c94b40db":[3,0,13,97,15],
 "classzyppng_1_1IODevice.html#ad24acd3ee7786444fba1d441c94b40db":[4,0,9,59,15],
 "classzyppng_1_1IODevice.html#ad61579caecb828206893cef8399b708c":[3,0,13,97,24],
-"classzyppng_1_1IODevice.html#ad61579caecb828206893cef8399b708c":[4,0,9,59,24],
-"classzyppng_1_1IODevice.html#ade05f3e0943d1d149259e91152320f61":[3,0,13,97,4],
-"classzyppng_1_1IODevice.html#ade05f3e0943d1d149259e91152320f61":[4,0,9,59,4]
+"classzyppng_1_1IODevice.html#ad61579caecb828206893cef8399b708c":[4,0,9,59,24]
 };
