@@ -1,5 +1,7 @@
 var NAVTREEINDEX94 =
 {
+"files.html":[5,0],
+"filestreambuf_8cc.html":[5,0,1,0,11],
 "filestreambuf_8cc_source.html":[5,0,1,0,11],
 "filestreambuf_8h.html":[5,0,1,0,12],
 "filestreambuf_8h_source.html":[5,0,1,0,12],
@@ -247,7 +249,5 @@ var NAVTREEINDEX94 =
 "idstring_8h_source.html":[5,0,1,6,2,2],
 "index.html":[],
 "inidict_8cc.html":[5,0,1,2,2],
-"inidict_8cc_source.html":[5,0,1,2,2],
-"inidict_8h.html":[5,0,1,2,3],
-"inidict_8h_source.html":[5,0,1,2,3]
+"inidict_8cc_source.html":[5,0,1,2,2]
 };
