@@ -1,5 +1,7 @@
 var NAVTREEINDEX95 =
 {
+"inidict_8h.html":[5,0,1,2,3],
+"inidict_8h_source.html":[5,0,1,2,3],
 "iniparser_8cc.html":[5,0,1,2,4],
 "iniparser_8cc_source.html":[5,0,1,2,4],
 "iniparser_8h.html":[5,0,1,2,5],
@@ -247,7 +249,5 @@ var NAVTREEINDEX95 =
 "namespaceztui.html#a042cb34225f69702e2963489788abe3c":[3,0,9,71],
 "namespaceztui.html#a047f328715808c0b44cbc1c10ad7dfed":[3,0,9,76],
 "namespaceztui.html#a086e61cd9ac6794a67536bc7bb99fd8d":[3,0,9,75],
-"namespaceztui.html#a08a51b72f130bee09c1c37fc90af5ac2":[3,0,9,68],
-"namespaceztui.html#a0b22ccecde71aac87fb0df895222c2db":[3,0,9,83],
-"namespaceztui.html#a0d32dedf250989f15cb2c3715893ff77":[3,0,9,32]
+"namespaceztui.html#a08a51b72f130bee09c1c37fc90af5ac2":[3,0,9,68]
 };
